<div class="quarto-about-jolla">
  <% partial('_image.ejs.html', { about, imgOpts: {} }) %> <%= about.title %><%=
  about.body %> <% if (about.links) { %>
  <hr class="about-sep" />
  <% } %> <% partial('_links.ejs.html', { about }) %>
</div>
