<div class="quarto-about-solana column-body">
  <div class="about-entity">
    <div class="entity-contents">
      <%= about.title %> <% partial('_links.ejs.html', { about }) %>
      <div class="about-contents"><%= about.body %></div>
    </div>
    <% partial('_image.ejs.html', { about, imgOpts: {} }) %>
  </div>
</div>
