<html xmlns="http://www.w3.org/1999/xhtml">    
  <head>      
    <title>Redirect to <%= url %></title>      
    <meta http-equiv="refresh" content="0;URL='<%= url %>'" />    
  </head>    
  <body> 
  </body>  
</html>     